@@ -125,27 +125,28 @@ class Domains:
 
 
 def add_domain(domain):
+    """Begin handling requests at given domain."""
     ip = get_ip()
+    onions = []
     with open("onion") as fp:
-        onion = fp.read()
+        onions.append(fp.read())
 
     domain_path = pathlib.Path("domains")
     with domain_path.open() as fp:
         domains = {domain: True for domain in fp.readlines()}
     domains[domain] = False
 
+    run_dir = "/home/gaea/app/run"
     nginx_conf_path = pathlib.Path("/etc/nginx/nginx.conf")
     with nginx_conf_path.open("w") as fp:
-        fp.write(web.host.templates.nginx(ip, onion, domains))
+        fp.write(str(web.host.templates.nginx(run_dir, ip, onions, domains)))
     subprocess.call(["sudo", "service", "nginx", "restart"])
 
     web.generate_cert(domain)
-    subprocess.call(["sudo", "cp", f"certs/{domain}/domain.key", "/etc/ssl/private"])
-    subprocess.call(["sudo", "cp", f"certs/{domain}/domain.crt", "/etc/ssl/certs"])
 
     domains[domain] = True
     with nginx_conf_path.open("w") as fp:
-        fp.write(web.host.templates.nginx(ip, onion, domains))
+        fp.write(str(web.host.templates.nginx(run_dir, ip, onions, domains)))
     subprocess.call(["sudo", "service", "nginx", "restart"])
 
     with domain_path.open("w") as fp:
